#
# spec file for package mangohud
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define internal_ver 0.6.8
%define imgui_ver 1.81
%define imgui_wrap 1
Name:           mangohud
Version:        0.6.8
Release:        bp155.2.6
Summary:        A Vulkan and OpenGL overlay for monitoring
License:        MIT
URL:            https://github.com/flightlessmango/MangoHud
Source0:        %{url}/archive/v%{internal_ver}.tar.gz#/%{name}-%{internal_ver}.tar.gz
Source1:        https://github.com/ocornut/imgui/archive/v%{imgui_ver}/imgui-%{imgui_ver}.tar.gz
Source2:        https://wrapdb.mesonbuild.com/v1/projects/imgui/%{imgui_ver}/%{imgui_wrap}/get_zip#/imgui-%{imgui_ver}-%{imgui_wrap}-wrap.zip
Source99:       baselibs.conf
BuildRequires:  AppStream
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  glslang-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-mako
BuildRequires:  unzip
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(spdlog)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(x11)
Suggests:       goverlay
Provides:       bundled(ImGui)

%description
A Vulkan and OpenGL overlay for monitoring FPS, temperatures, CPU/GPU load and more.

%prep
%autosetup -n MangoHud-%{internal_ver}
%autosetup -n MangoHud-%{internal_ver} -DTa1
%autosetup -n MangoHud-%{internal_ver} -DTa2
sed -i -e '1d;2i#!%{_bindir}/bash' bin/mangohud.in
sed -i 's,^@ld_libdir_mangohud@ ,%{_prefix}/\$LIB/mangohud/,' bin/mangohud.in
mv imgui-%{imgui_ver} subprojects/
sed -i 's/0.60.0/0.59/g' meson.build

%build
%meson \
 -Duse_system_vulkan=enabled \
 -Dwith_wayland=enabled \
 -Dwith_xnvctrl=disabled \
 -Duse_system_spdlog=enabled

%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/doc/%{name}/
%{_datadir}/vulkan/implicit_layer.d/
%{_mandir}/man1/mangohud.1%{?ext_man}
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/*/*/*/*.svg
%{_datadir}/metainfo/*.metainfo.xml

%changelog
* Sat Nov 26 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build by extracting the imgui to the versioned directory,
  where it belongs, as specified in the .wrap file (fixes build
  with meson 0.64, which got stricter on this front).
* Tue Aug  2 2022 Dead Mozay <dead_mozay@opensuse.org>
- Cleaning spec.
* Mon Aug  1 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.8:
  * Fixes MangoHud not loading with latest DXVK.
  * Use of system spdlog dependency.
  * Fixed table_columns not working as expected.
  * Minor adjustments to hud elements and imgui.
  * Added MANGOHUD_LOG_LEVEL env variable
    it takes off, info, err, warn.
  * Added FCAT support.
  * Disabled gamepad_battery_icon by default.
  * Generalize control over socket so it works with OpenGL as well.
  * AMDGPU: fixed gfx and cpu power metrics being parsed incorrectly.
  * fps_only disables legacy_layout by default.
* Sat May 14 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.7~1:
  * amdgpu: Prefer sysfs temp over gpu_metrics.
  * amdgpu: Fix incorrect gpu load for some GPUs.
  * amdgpu: If gpu_metrics is from v1_0, ignore it and
    use sysfs instead.
  * Fixed on screen benchmark not matching summary file.
  * Fixed zink detection.
  * disabled throttling_status by default for nvidia as it causes
    lag on 3000 series.
* Wed May  4 2022 Simon Vogl <simon.vogl@gmx.net>
- Update to version 0.6.7:
  * Show highest cpu freq instead of the cumulative average
  * Using sysfs scaling_cur_freq instead of /proc/cpuinfo for cpu core frequencies
  * Added EADesktop.exe and EALauncher.exe to blacklist
  * Logger writes a summary by default
  * Using gpu_metrics sysfs binary for amdgpu metrics
  * Showing min and max frametime for the period
  * Battery param shows a plug icon when plugged in
  * Improved amdgpu metrics accuracy by polling 100times per period
  * Fixed splitgate crashing on amd gpu's
  * Fixed not reporting amd cpu power when using the zenpower module
  * Fixed regression in hardware info updater
  * Fixed bug where setting cpu cores to offline would crash mangohud/mangoapp
* Sun Mar 13 2022 Simon Vogl <simon.vogl@gmx.net>
- Update to version 0.6.6 & 0.6.6.1:
  * fix mangoapp building without xnvctrl
  * Fixed logging crashing in some games (cyberpunk etc)
  * Limit keybind check to about 10hz (improves perf in high fps scenarios, like vkcube)
  * Added spdlog
  * Changed media_player_order to media_player_format={title};{artist};{album}. Semi-colon adds a new line.
- Switched to a new %%{internal_ver} macro for building as the internal version number 0.6.6-1 does not synergize with openSUSE's versioning system.
- Add spdlog as it is now required to build mangohud, don't use system spdlog as mangohud needs version 1.8.5 specifically.
* Fri Jul  9 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.5:
  * Fixed more issues where incorrect engine name would be shown.
  * ToGL detection.
  * middle-left and middle-right are now options in the position param.
  * Fixed issue where vulkan driver version would be incorrect.
* Thu Jun 24 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.4:
  * Fixed issue where some games would crash on startup.
  * Fixed issue where Battery param would cause a stutter.
  * Fixed issue where engine would incorrectly show "vulkan".
* Sat Jun 12 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.3:
  * core_load_change    Changes the colors of cpu core loads, uses the
    same data from cpu_load_value and cpu_load_change resolution
    Display the current resolution
  * show_fps_limit 	Display the current fps limit
  * custom_text_center 	Display a custom centered text, only works with legacy_layout=false
  * custom_text 	Display a custom text, only works with legacy_layout=false
  * exec 		Display output of bash command in next column, e.g
    custom_text=/home
    exec=df -h /home | tail -n 1. only works with legacy_layout=false
  * gamemode 		Displays whether gamemode is enabled or not
  * vkbasalt 		Displays whether vkbasalt is enabled or not
  * swap 		Displays swap space usage next to system RAM usage
  * battery 		Display current battery percent and energy consumption
  * battery_icon 	Display battery icon instead of percent
  * battery_color 	Change the BATT text color
  * round_corners 	Change the amount of roundness of the corners have e.g round_corners=10.0
* Wed Feb 10 2021 Dead Mozay <dead_mozay@opensuse.org>
- Add baselibs.conf for 32bit package.
* Mon Feb  1 2021 Dead Mozay <dead-mozay@opensuse.org>
- Fix LD_LIBRARY_PATH for 32bit apps (boo#1180826)
* Mon Nov 30 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.1:
  * Fix cpu power related crash
* Sun Nov 29 2020 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.6.0:
  * Fixed MangoHud OpenGL not showing in Black Ice
  * Fixed MangoHud OpenGL being a black box in Total War: MEDIEVAL II
  * Fixed MangoHud OpenGL not working in Divinity Original Sin
    Enhanced Edition
  * Fixed MangoHud OpenGL not working in Mount & Blade: Warband
  * Attempted fix for fps limit sometimes breaking
  * Fixed colors not updating
  * Moved frame_timing ms to above the graph instead of beside
  * Allow graphs to take up the entire region
  * Permitting more delimiters, , : and + are now acceptable
* Sun Oct 18 2020 Dead Mozay <dead-mozay@opensuse.org>
- Fix shebang
* Mon Aug 17 2020 dead_mozay@opensuse.org
- Update to version 0.5.1:
  * Fixed a memory leak in Source Engine 1 games (CSGO, TF2 etc)
  * You can use mangohud --dlsym as an alternative to
    MANGOHUD_DLSYM=1
  * MangoHud now comes with a man page man mangohud
  * output_file is now replaced by output_folder,
    the files are automatically named after the programs executable
  * By pressing Shift_L+F3 you will automatically upload the latest
    log file to Flightlessmango.com and open up said benchmark.
    To upload all logs for this session, the default keybind is
    Control_L=F3. Both of these require that you set the
    permit_upload param to 1 and output_folder
  * Added supported for more glyph ranges
* Fri Jun 12 2020 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
